# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: network_timezone_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='network_timezone_v1.proto',
  package='app.protobufs.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19network_timezone_v1.proto\x12\x10\x61pp.protobufs.v1\"A\n\x1cSavedNetworkTimezoneResponse\x12\x0f\n\x07network\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\"1\n\x1e\x44\x65letedNetworkTimezoneResponse\x12\x0f\n\x07network\x18\x01 \x01(\tb\x06proto3'
)




_SAVEDNETWORKTIMEZONERESPONSE = _descriptor.Descriptor(
  name='SavedNetworkTimezoneResponse',
  full_name='app.protobufs.v1.SavedNetworkTimezoneResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network', full_name='app.protobufs.v1.SavedNetworkTimezoneResponse.network', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='app.protobufs.v1.SavedNetworkTimezoneResponse.timezone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=112,
)


_DELETEDNETWORKTIMEZONERESPONSE = _descriptor.Descriptor(
  name='DeletedNetworkTimezoneResponse',
  full_name='app.protobufs.v1.DeletedNetworkTimezoneResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network', full_name='app.protobufs.v1.DeletedNetworkTimezoneResponse.network', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=163,
)

DESCRIPTOR.message_types_by_name['SavedNetworkTimezoneResponse'] = _SAVEDNETWORKTIMEZONERESPONSE
DESCRIPTOR.message_types_by_name['DeletedNetworkTimezoneResponse'] = _DELETEDNETWORKTIMEZONERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SavedNetworkTimezoneResponse = _reflection.GeneratedProtocolMessageType('SavedNetworkTimezoneResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEDNETWORKTIMEZONERESPONSE,
  '__module__' : 'network_timezone_v1_pb2'
  # @@protoc_insertion_point(class_scope:app.protobufs.v1.SavedNetworkTimezoneResponse)
  })
_sym_db.RegisterMessage(SavedNetworkTimezoneResponse)

DeletedNetworkTimezoneResponse = _reflection.GeneratedProtocolMessageType('DeletedNetworkTimezoneResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDNETWORKTIMEZONERESPONSE,
  '__module__' : 'network_timezone_v1_pb2'
  # @@protoc_insertion_point(class_scope:app.protobufs.v1.DeletedNetworkTimezoneResponse)
  })
_sym_db.RegisterMessage(DeletedNetworkTimezoneResponse)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: updates_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='updates_v1.proto',
  package='app.protobufs.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10updates_v1.proto\x12\x10\x61pp.protobufs.v1\"#\n\x12UpdatedAppResponse\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\x62\x06proto3'
)




_UPDATEDAPPRESPONSE = _descriptor.Descriptor(
  name='UpdatedAppResponse',
  full_name='app.protobufs.v1.UpdatedAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='app.protobufs.v1.UpdatedAppResponse.force', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=73,
)

DESCRIPTOR.message_types_by_name['UpdatedAppResponse'] = _UPDATEDAPPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpdatedAppResponse = _reflection.GeneratedProtocolMessageType('UpdatedAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDAPPRESPONSE,
  '__module__' : 'updates_v1_pb2'
  # @@protoc_insertion_point(class_scope:app.protobufs.v1.UpdatedAppResponse)
  })
_sym_db.RegisterMessage(UpdatedAppResponse)


# @@protoc_insertion_point(module_scope)
